/*
 * Copyright (c) 2006-2009 CNRS/LAAS
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */



#include <sys/time.h>

#include "msgStruct.h"


#ifndef __GPS_NOVATEL_OEM4
#define __GPS_NOVATEL_OEM4


/////////////////////////////////////////////////////////////////
//
// ID des messages binaires et des champs binaires
//
/////////////////////////////////////////////////////////////////
enum BINARY_MESSAGE
  {
    BESTPOSb = 0x2a,
    BESTUTMb = 0x2d6,
    BESTVELb = 0x63,
    BESTXYZb = 0xf1
  };

/////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////
//
// Definition des structures globale pour traiter les trames em
// mode RTK
//
/////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////


////////////////////////// Tableau de structure
typedef union OEM4_TRAME_TYPE
{
  OEM4BESTPOSb_LOG strOEM4BESTPOSb_LOG;
  OEM4BESTUTMb_LOG strOEM4BESTUTMb_LOG;
  OEM4BESTVELb_LOG strOEM4BESTVELb_LOG;
  OEM4BESTXYZb_LOG strOEM4BESTXYZb_LOG;
} OEM4_TRAME_TYPE;



// Dfinition du header + de la trame dcode binaire, cette structure
// est utilise ensuite pour toutes les trames
typedef struct OEM4_TRAME_COMPUTED
{ 
  // Heure systeme
  struct timeval timev;
  
  // Header de la trame binaire
  OEM4_BINARY_HEADER BINARY_HEADER;
  
  // Trame dcode
  OEM4_TRAME_TYPE TRAME_TYPE;
  
}OEM4_TRAME_COMPUTED;


#define MAX_TRAME_COMPUTED 10

OEM4_TRAME_COMPUTED USR_TRAME[MAX_TRAME_COMPUTED];

#endif


/////////////////////////////////////////////////////////////////
//
// Chechsum trame binaire
//
/////////////////////////////////////////////////////////////////
#ifndef __CRC32_H
#define __CRC32_H

int TestASCII(  char* ucBuf_ );
int TestBinary( unsigned char* ucBuf_, int iSize_ );

unsigned long CalculateCRC(unsigned char* ucBuf_, int iSize_);

#endif

